@@ -215,13 +215,26 @@ func TestRcPaths(t *testing.T) {
 func TestRcConfigUnlock(t *testing.T) {
 	call := rc.Calls.Get("config/unlock")
 	assert.NotNil(t, call)
+
 	in := rc.Params{
-		"config_password": "test",
+		"configPassword": "test",
 	}
 	out, err := call.Fn(context.Background(), in)
 	require.NoError(t, err)
-
-	assert.Nil(t, err)
 	assert.Nil(t, out)
 
+	in = rc.Params{
+		"config_password": "test",
+	}
+	out, err = call.Fn(context.Background(), in)
+	require.NoError(t, err)
+	assert.Nil(t, out)
+
+	in = rc.Params{
+		"bad_config_password": "test",
+	}
+	out, err = call.Fn(context.Background(), in)
+	require.Error(t, err)
+	assert.ErrorContains(t, err, `Didn't find key "configPassword" in input`)
+	assert.Nil(t, out)
 }
