@@ -14,10 +14,6 @@ import (
 	"golang.org/x/net/ipv6"
 )
 
-func dialContext(ctx context.Context, network, address string, ci *fs.ConfigInfo) (net.Conn, error) {
-	return NewDialer(ctx).DialContext(ctx, network, address)
-}
-
 // Dialer structure contains default dialer and timeout, tclass support
 type Dialer struct {
 	net.Dialer
@@ -31,10 +27,10 @@ func NewDialer(ctx context.Context) *Dialer {
 	ci := fs.GetConfig(ctx)
 	dialer := &Dialer{
 		Dialer: net.Dialer{
-			Timeout:   ci.ConnectTimeout,
+			Timeout:   time.Duration(ci.ConnectTimeout),
 			KeepAlive: 30 * time.Second,
 		},
-		timeout: ci.Timeout,
+		timeout: time.Duration(ci.Timeout),
 		tclass:  int(ci.TrafficClass),
 	}
 	if ci.BindAddr != nil {
