@@ -5,6 +5,7 @@ import (
 	"runtime"
 	"testing"
 
+	"github.com/rclone/rclone/vfs"
 	"github.com/rclone/rclone/vfs/vfscommon"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -15,7 +16,7 @@ func TestWriteFileNoWrite(t *testing.T) {
 	run.skipIfNoFUSE(t)
 
 	fd, err := osCreate(run.path("testnowrite"))
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	err = fd.Close()
 	assert.NoError(t, err)
@@ -110,6 +111,9 @@ func TestWriteFileDup(t *testing.T) {
 
 	var dupFd uintptr
 	dupFd, err = writeTestDup(fh.Fd())
+	if err == vfs.ENOSYS {
+		t.Skip("dup not supported on this platform")
+	}
 	require.NoError(t, err)
 
 	dupFile := os.NewFile(dupFd, fh.Name())
